from ._hxml import VenturaXML
import ventura._hzip as hzip
import ventura._hweb as hweb
import ventura._hpath as hpath

__author__ = 'Hermes Passer'

def update_if_is_need(version, xml_url, path = ''):
	# download and read xml
	xml_text = hweb.get_page(xml_url)
	
	ventura = VenturaXML(xml_text, version)
	if ventura.is_updated():
		return False
	
	links = ventura.get_links()
	for link in links:
		path = path + '//' if path != '' else ''
		hweb.download(link, path + 'update.zip')
		hzip.extract(path + 'update.zip', path)
	
	hpath.delete_files(ventura.get_files_to_delete())
	return True



import zipfile
import os

def extract(file_url, path_to_extract):
	# load zip file
	zip_file = zipfile.ZipFile(file_url, 'r')
	# extract in the folder
	zip_file.extractall(path_to_extract)
	# close zip
	zip_file.close()
	# delete zip file
	os.remove(file_url)



import pathlib
import shutil
import os

def load_file(name):
	file = open(name, 'r')
	text = file.read()
	file.close()
	return text

def create_dir(dir):	
	dir = os.path.dirname(dir)
	if dir == '':
		return
	
	path = pathlib.Path(dir)
	path.mkdir(parents = True, exist_ok = True) 

def	is_folder(text):
	return text.endswith("\\")

def remove_file(file):
	if os.path.isfile(file):
		os.remove(file)
		
def remove_folder(folder):
	if os.path.isdir(folder):
		shutil.rmtree(folder)
	
def delete_files(files):
	for file in files:
		if is_folder(file):
			remove_folder(file)
		else:
			remove_file(file)



import xml.etree.ElementTree as ET
import operator
import os

class UpdateNode:
	def __init__(self, version, node):
		self.node = node
		self.version = version

class VenturaXML:
	def __init__(self, xml_text, program_version):
		self.root = ET.fromstring(xml_text)
		self.current_version = program_version
		self.get_latest()
	
	def is_updated(self):
		return self.current_version >= self.last_version
			
	def	get_files_to_delete(self):
		all_files = []
		for update_node in self.update_nodes:
			if (update_node != None):
				del_txt = update_node.node.find('.//delete').text
				all_files += del_txt.split(',') if del_txt != None else ''
				
		return all_files
	
	def get_links(self):
		links = []
		for update_node in self.update_nodes:
			if (update_node != None):
				link = update_node.node.find('.//url').text
				links.append(link) if link != None else ''
		
		return links
	
	# Get newer update nodes and it versions
	def get_latest(self):		
		nodes = self.root.findall('.//update')		
		versions = []
		for node in nodes:
			ver = float(node.attrib['version'])
			if (ver > self.current_version):
				versions.append(UpdateNode(ver, node))
		
		if (versions == []):
			self.last_version = self.current_version
			self.update_nodes = None
			return
		
		# sort value
		versions = sorted(versions, key = operator.attrgetter('version'))
		self.last_version = versions[len(versions) - 1].version
		self.update_nodes = versions




from setuptools import setup

setup(
      name = 'ventura',
      version = '0.2',
      description = 'Simple xml-based updater in python 3.6 with no try-catch statement',
      url = 'http://github.com/hermespasser/ventura',
      author = 'Hermes Passer',
      author_email = 'hermespasser@gmail.com',
      license = 'MIT',
      packages = ['ventura']
)



import urllib.request as req
import ventura._hpath as hpath
import os

def download(url, file_name):
	response = req.urlopen(url)
	
	# Create folders if need
	hpath.create_dir(file_name)
	
	file = open(file_name,'wb')
	file.write(response.read()) 
	file.close()

def get_page(url):
	response = req.urlopen(url)
	return response.read().decode("utf8")
